@@ -1,7 +1,7 @@
 // qsynthChannelsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -43,8 +43,7 @@
 // qsynthChannelsForm -- UI wrapper form.
 
 // Constructor.
-qsynthChannelsForm::qsynthChannelsForm (
-	QWidget *pParent, Qt::WindowFlags wflags )
+qsynthChannelsForm::qsynthChannelsForm ( QWidget *pParent, Qt::WindowFlags wflags )
 	: QWidget(pParent, wflags)
 {
 	// Setup UI struct...
@@ -68,7 +67,7 @@ qsynthChannelsForm::qsynthChannelsForm (
 
 	// Set validators...
 	m_ui.PresetComboBox->setValidator(
-		new QRegExpValidator(QRegExp("[\\w-]+"), m_ui.PresetComboBox));
+		new QRegularExpressionValidator(QRegularExpression("[\\w-]+"), m_ui.PresetComboBox));
 
 	// Soundfonts list view...
 	QHeaderView *pHeader = m_ui.ChannelsListView->header();
