@@ -2,6 +2,7 @@
 
    Skulpture - Classical Three-Dimensional Artwork for Qt 4
 
+   Copyright (c) 2019 rncbc aka Rui Nuno Capela <rncbc@rncbc.org>
    Copyright (c) 2007-2009 Christoph Feck <christoph@maxiom.de>
 
    This program is free software; you can redistribute it and/or
@@ -28,8 +29,8 @@
 class qsynthDialSkulptureStyle : public QCommonStyle
 {
 public:
-    qsynthDialSkulptureStyle() {};
-    virtual ~qsynthDialSkulptureStyle() {};
+    qsynthDialSkulptureStyle() {}
+    virtual ~qsynthDialSkulptureStyle() {}
 
     virtual void drawComplexControl(ComplexControl cc, const QStyleOptionComplex *opt, QPainter *p,
                                     const QWidget *widget = 0) const;
