@@ -29,7 +29,7 @@
 #include <QMouseEvent>
 #include <QWheelEvent>
 
-#include <cmath>
+#include <QtMath>
 
 
 //-------------------------------------------------------------------------
@@ -73,7 +73,7 @@ float qsynthKnob::mouseAngle ( const QPoint& pos )
 // Alternate mouse behavior event handlers.
 void qsynthKnob::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
-	if (pMouseEvent->button() == Qt::MidButton) {
+	if (pMouseEvent->button() == Qt::MiddleButton) {
 		// Reset to default value...
 		if (m_iDefaultValue < minimum() || m_iDefaultValue > maximum())
 			m_iDefaultValue = (maximum() + minimum()) / 2;
@@ -136,7 +136,7 @@ void qsynthKnob::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 
 void qsynthKnob::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 {
-	if (m_dialMode == DefaultMode && pMouseEvent->button() != Qt::MidButton) {
+	if (m_dialMode == DefaultMode && pMouseEvent->button() != Qt::MiddleButton) {
 		QDial::mouseReleaseEvent(pMouseEvent);
 	} else if (m_bMousePressed) {
 		m_bMousePressed = false;
