@@ -1,7 +1,7 @@
 // qsynthSystemTray.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,7 +44,7 @@ qsynthSystemTray::qsynthSystemTray ( QWidget *pParent )
 	#if QT_VERSION < QT_VERSION_CHECK(6, 1, 0)
 		m_icon = QIcon(":/images/qsynth.png");
 	#else
-		m_icon = pParent->windowIcon();
+		m_icon = pParent->windowIcon().pixmap(32, 32);
 	#endif
 		setBackground(Qt::transparent); // also updates pixmap.
 		QSystemTrayIcon::setIcon(m_icon);
